@@ -25,6 +25,7 @@
 
 #define __GNOME_GLYPHLIST_C__
 
+#include "config.h"
 #include <string.h>
 #include "gnome-glyphlist-private.h"
 
@@ -91,6 +92,7 @@ gnome_glyphlist_unref (GnomeGlyphList *gl)
 			g_free (gl->rules);
 			gl->rules = NULL;
 		}
+		g_free (gl);
 	}
 
 	return NULL;
