@@ -25,6 +25,7 @@
 
 #define __GNOME_PRINT_FRGBA_C__
 
+#include "config.h"
 #include <math.h>
 #include <string.h>
 
@@ -35,6 +36,7 @@
 #include <libart_lgpl/art_vpath_bpath.h>
 
 #include "gnome-print-private.h"
+#include "gp-gc-private.h"
 #include "gnome-print-rbuf.h"
 #include "gnome-print-meta.h"
 #include "gnome-print-frgba.h"
@@ -411,8 +413,10 @@ gpf_render_buf (GnomePrintFRGBA * frgba, ArtDRect * box)
 	w = (gint) width;
 	h = (gint) height;
 
-	if (width <= 0) return;
-	if (height <= 0) return;
+	if (width <= 0)
+		return;
+	if (height <= 0)
+		return;
 
 	pixels = g_new (guchar, w * h * 3);
 
@@ -423,11 +427,11 @@ gpf_render_buf (GnomePrintFRGBA * frgba, ArtDRect * box)
 	art_affine_multiply (page2buf, page2buf, a);
 
 	gpr = gnome_print_rbuf_new (pixels,
-			w,
-			h,
-			w * 3,
-			page2buf,
-			FALSE);
+				    w,
+				    h,
+				    w * 3,
+				    page2buf,
+				    FALSE);
 
 	gnome_print_meta_render_data (gpr,
 				      gnome_print_meta_get_buffer (GNOME_PRINT_META (frgba->meta)),
