@@ -298,6 +298,8 @@ gnome_print_job_close (GnomePrintJob *job)
 		return gnome_print_context_close (job->meta);
 	}
 
+	g_warning ("gnome_print_job_close can only be called once\n");
+
 	return GNOME_PRINT_ERROR_UNKNOWN;
 }
 
@@ -332,6 +334,12 @@ gnome_print_job_print (GnomePrintJob *job)
 
 	pp = job->priv;
 
+	if (!pp->closed) {
+		g_warning ("You should call gnome_print_job_close before calling\n"
+			   "gnome_print_job_print\n");
+		gnome_print_job_close (job);
+	}
+	
 	ctx = gnome_print_context_new (job->config);
 	g_return_val_if_fail (ctx != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
