@@ -35,6 +35,7 @@
  *
  */
 
+#include "config.h"
 #include <math.h>
 #include <string.h>
 
@@ -215,10 +216,7 @@ gpb_showpage (GnomePrintContext * pc)
 static gint
 gpb_clip (GnomePrintContext * pc, const ArtBpath *bpath, ArtWindRule rule)
 {
-#ifdef __GNUC__
-#warning Why is are we not clipping?
-#endif
-	
+	/* FIXME: Why are we not clipping? */
 #if 0
 	GnomePrintRBuf * rbuf;
 
