@@ -104,6 +104,8 @@ gnome_print_transport_finalize (GObject *object)
 gint
 gnome_print_transport_construct (GnomePrintTransport *transport, GnomePrintConfig *config)
 {
+	GnomePrintReturnCode retval = GNOME_PRINT_ERROR_UNKNOWN;
+	
 	g_return_val_if_fail (transport != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_TRANSPORT (transport), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (config != NULL, GNOME_PRINT_ERROR_UNKNOWN);
@@ -113,9 +115,9 @@ gnome_print_transport_construct (GnomePrintTransport *transport, GnomePrintConfi
 	transport->config = gnome_print_config_ref (config);
 
 	if (GNOME_PRINT_TRANSPORT_GET_CLASS (transport)->construct)
-		GNOME_PRINT_TRANSPORT_GET_CLASS (transport)->construct (transport);
+		retval = GNOME_PRINT_TRANSPORT_GET_CLASS (transport)->construct (transport);
 
-	return TRUE;
+	return retval;
 }
 
 gint
@@ -231,6 +233,7 @@ gnome_print_transport_new_from_module_name (const gchar *module_name, GnomePrint
 
 	if (!module) {
 		insert = TRUE;
+		g_free (path);
 		path = g_module_build_path (GNOME_PRINT_MODULES_DIR, module_name);
 		module = g_module_open (path, G_MODULE_BIND_LAZY);
 	}
@@ -247,7 +250,8 @@ gnome_print_transport_new_from_module_name (const gchar *module_name, GnomePrint
 	if (!g_module_symbol (module, "gnome_print__transport_get_type", &get_type)) {
 		g_warning ("Missing gnome_print__transport_get_type in %s\n", path);
 		g_module_close (module);
-		g_free (path);
+		if (path)
+			g_free (path);
 		return NULL;
 	}
 
@@ -255,10 +259,14 @@ gnome_print_transport_new_from_module_name (const gchar *module_name, GnomePrint
 	if (transport == NULL) {
 		g_warning ("Could not create transport in %s\n", path);
 		g_module_close (module);
-		g_free (path);
+		if (path)
+			g_free (path);
 		return NULL;
 	}
 
+	if (path)
+		g_free (path);
+	
 	return transport;
 }
 
@@ -289,6 +297,7 @@ gnome_print_transport_create (gpointer get_type, GnomePrintConfig *config)
 	GnomePrintTransport *transport;
 	GType (* transport_get_type) (void);
 	GType type;
+	GnomePrintReturnCode retval;
 
 	transport_get_type = get_type;
 
@@ -296,8 +305,10 @@ gnome_print_transport_create (gpointer get_type, GnomePrintConfig *config)
 	g_return_val_if_fail (g_type_is_a (type, GNOME_TYPE_PRINT_TRANSPORT), NULL);
 
 	transport = g_object_new (type, NULL);
-	gnome_print_transport_construct (transport, config);
+	retval = gnome_print_transport_construct (transport, config);
+
+	if (retval != GNOME_PRINT_OK)
+		return NULL;
 
 	return transport;
 }
-
