@@ -123,7 +123,7 @@ gnome_print_context_finalize (GObject *object)
 gint
 gnome_print_context_construct (GnomePrintContext *pc, GnomePrintConfig *config)
 {
-	GnomePrintReturnCode retval = GNOME_PRINT_ERROR_UNKNOWN;
+	GnomePrintReturnCode retval = GNOME_PRINT_OK;
 	
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_UNKNOWN);
@@ -135,7 +135,7 @@ gnome_print_context_construct (GnomePrintContext *pc, GnomePrintConfig *config)
 
 	if (GNOME_PRINT_CONTEXT_GET_CLASS (pc)->construct)
 		retval = GNOME_PRINT_CONTEXT_GET_CLASS (pc)->construct (pc);
-
+	
 	return retval;
 }
 
