@@ -289,7 +289,7 @@ gpa_printer_new_from_tree (xmlNodePtr tree)
 			xmlChar *model_id;
 			model_id = xmlNodeGetContent (xml_node);
 			if (model_id && *model_id) {
-				model = gpa_model_get_by_id (model_id);
+				model = gpa_model_get_by_id (model_id, FALSE);
 				if (!model) {
 					g_warning ("Could not find model by id:%s for printer:%s\n",
 						   model_id, printer_id);
